@@ -1,13 +1,15 @@
-from .main import http,testInternet
+from .main import http,testInternet,setDefaultTestingUrl,setDefaultTimeout
 
 __all__=[
     'http',
     'testInternet',
+    'setDefaultTestingUrl',
+    'setDefaultTimeout'
 ]
 
 
-__version__='0.9.2'
-__license__='GPL v2'
+__version__='0.9.3'
+__license__='GPL-2.0 License'
 __author__='Tiancheng Jiao'
 __github__='https://github.com/jtc1246/easy-http'
 __author_email__='jtc1246@outlook.com'
