@@ -1,19 +1,53 @@
 import urllib3
 import urllib3.exceptions as exceptions
 from .others import *
+
+defaultTestingUrl='https://apple.com'
+useDefaultTestingUrl=True
+defaultTimeOut=2000
+
+def setDefaultTimeout(timeout:int):
+    global defaultTimeOut
+    defaultTimeOut=timeout
+
+def setDefaultTestingUrl(url:str):
+    global defaultTestingUrl,useDefaultTestingUrl
+    defaultTestingUrl=url
+    useDefaultTestingUrl=False
+
 def testInternet():
+    global defaultTestingUrl,useDefaultTestingUrl
     http1=urllib3.PoolManager()
+    dic={True:3,False:1}
     try:
-        r=http1.request("GET",'https://apple.com',timeout=3,retries=False)
+        r=http1.request("GET",defaultTestingUrl,dic[useDefaultTestingUrl],retries=False)
     except:
         return -1
     return 0
 
-def http(url:str,Method:str="GET",Header:dict={},Timeout:int=2000,ToJson:bool=True,Body:str="",Decode:bool=True):
-    # status:  -1: 无网络  -2: 超时  -3: 域名不存在  -4: 其它问题, 主要是代理服务器设置错误(服务器上无此问题)
-    # status:  1: 不是 UTF-8 编码, text 返回空字符串  2: 不是json格式(在toJSON=True的前提下)
-    # status:  3: 对方网站不支持https, 但是却使用了https连接, 这种情况会自动切换为http连接, 若此次status不为0, 返回该status, 若为0, 返回3
+def http(url:str,Method:str="GET",Header:dict={},Timeout:int=None,ToJson:bool=True,Body:str="",Decode:bool=True):
+    '''
+    About Timeout:
+        Default timeout is 2000ms.
+        If the paramater Timeout is None, it will use dafault timeout.
+        If you want to specify a timeout, just give a value to Timeout, unit is ms.
+        You can set default timeout by using 
+    
+    关于 status / About status:
+        -1: 无网络 / No Internet Connection
+        -2: 超时 / Timeout
+        -3: 域名不存在 / Domian not exists
+        -4: 其它问题, 主要是代理服务器设置错误 / Other problen, mainly proxy server error
+
+        1: 不是 UTF-8 编码, text 返回空字符串 / Not UTF-8 encode, the return value of text will be empty str
+        2: 不是 Json 格式(在 toJSON=True 的前提下) / Not in Json format (when toJSON=True)
+        3: 对方网站不支持https, 但是却使用了https连接, 这种情况会自动切换为http连接, 若此次status不为0, 返回该status, 若为0, 返回3 / 
+        The website does not support https. It will change to http automatically in this situation. If the status this time is 0, the status will be 3. If not 0, it will return this status.
+    '''
+    global defaultTimeOut
     backup=[url,Method,Header,Timeout,ToJson,Body,Decode]
+    if(Timeout==None):
+        Timeout=defaultTimeOut
     http1=urllib3.PoolManager()
     r=0
     if(ToJson):
